==> bdfn-1.0.11.tgz: package/src/utils/Messages.js <==
const Discord = require('discord.js-light');

class bdfnEmbed {
    constructor() {
        this.embedSchema = new Discord.MessageEmbed();
    }

    async title(title = String) {
        this.embedSchema.setTitle(title ?? 'untitled');
    }

    async author(name = String, iconURL = String, url = String) {
        this.embedSchema.setAuthor({
            name: name,
            iconURL: iconURL,
            url: url
        });
    }

    async color(color = String) {
        this.embedSchema.setColor(color ?? 'RANDOM');
    }

    async description(description = String) {
        this.embedSchema.setDescription(description ?? 'hello world');
    }

    async thumbnail(url = String) {
        this.embedSchema.setThumbnail(url);
    }

    async fields(fields = Array) {
        for(let field of fields) {
            this.embedSchema.addField(field[0], field[1], field[2]? field[2] : false);
        }
    }

    async field(name = String, description = String, inline = Boolean) {
        this.embedSchema.addField(name, description, inline);
    }

    async image(url = String) {
        this.embedSchema.setImage(url);
    }

    async timestamp(type) {
        this.embedSchema.setTimestamp(type);
    }

    async footer(text = String, iconURL = String) {
        this.embedSchema.setFooter({
            text: text,
            iconURL: iconURL
        });
    }
}

module.exports = {
    send: async (channel, obj) => {
        await Discord._client.channels.fetch(channel.id);
        channel.send(obj).catch();
    },

    reply: async (channel, obj) => {
        await Discord._client.channels.fetch(channel.id);
        channel.reply(obj).catch();
    },

    userSend: async (user, obj) => {
        user = Discord._client.users.cache.get(user.id) || await Discord._client.users.fetch(user.id);
        user.send(obj).catch();
    },

    bdfnEmbed
};

==> bdfn-1.1.0.tgz: package/src/utils/Messages.js <==
const Discord = require('discord.js');

class bdfnEmbed {
    constructor() {
        this.embedSchema = new Discord.EmbedBuilder();
    }

    async title(title = String) {
        this.embedSchema.setTitle(title ?? 'untitled');
    }

    async author(name = String, iconURL = String, url = String) {
        this.embedSchema.setAuthor({
            name: name,
            iconURL: iconURL,
            url: url
        });
    }

    async color(color = String) {
        this.embedSchema.setColor(color ?? 'RANDOM');
    }

    async description(description = String) {
        this.embedSchema.setDescription(description ?? 'hello world');
    }

    async thumbnail(url = String) {
        this.embedSchema.setThumbnail(url);
    }

    async fields(fields = Array) {
        this.embedSchema.addFields(fields);
    }

    async image(url = String) {
        this.embedSchema.setImage(url);
    }

    async timestamp(type) {
        this.embedSchema.setTimestamp(type);
    }

    async footer(text = String, iconURL = String) {
        this.embedSchema.setFooter({
            text: text,
            iconURL: iconURL
        });
    }
}

module.exports = {
    send: async (channel, obj) => {
        await Discord._client.channels.fetch(channel.id);
        channel.send(obj).catch();
    },

    reply: async (channel, obj) => {
        await Discord._client.channels.fetch(channel.id);
        channel.reply(obj).catch();
    },

    userSend: async (user, obj) => {
        user = Discord._client.users.cache.get(user.id) || await Discord._client.users.fetch(user.id);
        user.send(obj).catch();
    },

    bdfnEmbed
};
